@@ -112,6 +112,9 @@ class R3sponse(object):
 		# the message.
 		message=None,
 		# option 2:
+		# the error.
+		error=None,
+		# option 3:
 		# the response dict (leave message None to use).
 		response={},
 		# optionals:
@@ -123,14 +126,16 @@ class R3sponse(object):
 		save_errors=False,
 	):
 		msg, _error_ = None, False
-		if [message,response] == [None,{}]:
-			raise ValueError("Define either parameter [message:str] or [response:dict].")
+		if [message,error,response] == [None,None,{}]:
+			raise ValueError("Define either parameter [message:str], [error:str] or [response:dict].")
 		if response != {}:
 			if response["error"] != None: 
 				_error_ = True
 				msg = f"Error: {response['error']}"
 			else: 
 				msg = response["message"]
+		elif error != None: 
+			msg = f"Error: {error}"
 		else: 
 			msg = message
 		if log_level >= self.log_level:
